@@ -1,4 +1,4 @@
-from flask import request, url_for
+from flask import request, url_for, redirect
 import flask
 
 
@@ -6,6 +6,10 @@ def current_for(**values):
     return url_for(request.endpoint, **values)
 
 
+def redirect_for(endpoint, **values):
+    return redirect(url_for(endpoint, **values))
+
+
 class Request(flask.Request):
     @property
     def is_get(self):
